Documentation
¶
Index ¶
- Constants
- Variables
- type Controller
- type Coreproxy
- type Gui
- func (g *Gui) FileSaveAs(s string) bool
- func (g *Gui) GetModuleGui() interface{}
- func (g *Gui) GetSettings() interface{}
- func (g *Gui) HideAllTabs()
- func (g *Gui) SetRightClickMenu()
- func (g *Gui) SetTableModel(m *model.SortFilterModel)
- func (g *Gui) ShowEditedReqTab(editedReq string)
- func (g *Gui) ShowEditedRespTab(editedResp string)
- func (g *Gui) ShowReqTab(req string)
- func (g *Gui) ShowRespTab(resp string)
- func (g *Gui) Title() string
- type Settings
Constants ¶
const ( CopyURLLabel = "Copy URL" CopyBaseURLLabel = "Copy base URL" RepeatLabel = "Repeat" ClearHistoryLabel = "Clear History" AddToScopeLabel = "Add Host to Scope" )
Variables ¶
var Stg = &Settings{ IP: "127.0.0.1", Port: 8080, Interceptor: false, ReqIntercept: true, RespIntercept: false, }
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
core.ControllerModule
Module *Coreproxy
Gui *Gui
Sess *core.Session
Filter *model.Filter
// contains filtered or unexported fields
}
Controller represents the controller for the main intercetp proxy
func LoadCoreProxyModule ¶
func LoadCoreProxyModule(s *core.Session) *Controller
LoadCoreProxyModule loads the core proxy module in the given session
func NewController ¶
func NewController(proxy *Coreproxy, proxygui *Gui, s *core.Session) *Controller
NewController creates a new controller for the core intercetp proxy
func (*Controller) ExecCommand ¶
func (c *Controller) ExecCommand(m string, args ...interface{})
ExecCommand execs commands submitted by other modules
func (*Controller) GetGui ¶
func (c *Controller) GetGui() core.GuiModule
GetGui returns the Gui of the current controller
func (*Controller) GetModule ¶
func (c *Controller) GetModule() core.Module
GetModule returns the module of the current controller
type Coreproxy ¶
type Coreproxy struct {
core.Module
Sess *core.Session
Address string
Port int
Proxyh *goproxy.ProxyHttpServer
Req int
Resp int
Srv *http.Server
OnReq func(*http.Request, *goproxy.ProxyCtx) (*http.Request, *http.Response)
OnResp func(*http.Response, *goproxy.ProxyCtx) *http.Response
// contains filtered or unexported fields
}
Coreproxy represents the intercept proxy
func NewCoreProxy ¶
NewCoreProxy creates a new intercept proxy
func (*Coreproxy) ChangeIPPort ¶
ChangeIPPort is used to change the ip and port of the current intercept proxy
func (*Coreproxy) Description ¶
Description returns the description of the current module
type Gui ¶
type Gui struct {
core.GuiModule
Sess *core.Session
ControllerInit func()
StartProxy func(bool)
StopProxy func()
RowClicked func(int)
ApplyFilters func(bool)
ResetFilters func(bool)
CheckReqInterception func(bool)
CheckRespInterception func(bool)
CheckIgnoreHTTPS func(bool)
SaveCAClicked func(bool)
RightItemClicked func(string, int)
RequestTextEdit *widgets.QPlainTextEdit
EditedRequestTextEdit *widgets.QPlainTextEdit
ResponseTextEdit *widgets.QPlainTextEdit
EditedResponseTextEdit *widgets.QPlainTextEdit
// Filter
TextSearchLineEdit *widgets.QLineEdit
ShowScopeOnlyCheckBox *widgets.QCheckBox
ScopeLineEdit *widgets.QLineEdit
ApplyFiltersButton *widgets.QPushButton
ResetFiltersButton *widgets.QPushButton
S100CheckBox *widgets.QCheckBox
S200CheckBox *widgets.QCheckBox
S300CheckBox *widgets.QCheckBox
S400CheckBox *widgets.QCheckBox
S500CheckBox *widgets.QCheckBox
ShowExtensionLineEdit *widgets.QLineEdit
HideExtensionLineEdit *widgets.QLineEdit
ShowOnlyCheckBox *widgets.QCheckBox
HideOnlyCheckBox *widgets.QCheckBox
// settings tab
ListenerLineEdit *widgets.QLineEdit
StartStopButton *widgets.QPushButton
ReqInterceptCheckBox *widgets.QCheckBox
RespInterceptCheckBox *widgets.QCheckBox
SaveCAButton *widgets.QPushButton
// interceptor
ForwardButton *widgets.QPushButton
DropButton *widgets.QPushButton
InterceptorToggleButton *widgets.QPushButton
InterceptorTextEdit *widgets.QPlainTextEdit
Toggle func(bool)
Forward func(bool)
Drop func(bool)
// contains filtered or unexported fields
}
Gui represents the GUI of the main intercept proxy
func (*Gui) GetModuleGui ¶
func (g *Gui) GetModuleGui() interface{}
GetModuleGui returns the Gui for the current module
func (*Gui) GetSettings ¶
func (g *Gui) GetSettings() interface{}
func (g *Gui) settingsTabGui() widgets.QWidget_ITF {
func (*Gui) HideAllTabs ¶
func (g *Gui) HideAllTabs()
HideAllTabs hides the tabs used to view details of a single row in the history table
func (*Gui) SetRightClickMenu ¶
func (g *Gui) SetRightClickMenu()
SetRightClickMenu sets the menu items when right clicking an item in the history table
func (*Gui) SetTableModel ¶
func (g *Gui) SetTableModel(m *model.SortFilterModel)
SetTableModel sets the table model along with some column width to use in the history table
func (*Gui) ShowEditedReqTab ¶
ShowEditedReqTab shows the edited request tab for the currently selected item in the history table
func (*Gui) ShowEditedRespTab ¶
ShowEditedRespTab shows the edited response tab for the currently selected item in the history table
func (*Gui) ShowReqTab ¶
ShowReqTab shows the request tab for the currently selected item in the history table
func (*Gui) ShowRespTab ¶
ShowRespTab shows the response tab for the currently selected item in the history table